dnl progbase.m4 -- Autoconf macro for locating progbase from configure.ac
dnl of third-party software packages.
dnl This file is part of PROGBASE.
dnl
dnl PROGBASE - A library of core functions to simplify program development
dnl ----------------------------------------------------------------------
dnl
dnl PROGBASE provides a set of core functions to speed up the writing of
dnl new programs without the need to first build up the program's "base".
dnl It includes functions for logging, memory management, file operations,
dnl inter-process communication, linked lists, process handling and time
dnl based execution.
dnl
dnl Copyright (C) 2005 Peter Pramberger
dnl
dnl PROGBASE is free software; you can redistribute it and/or modify
dnl it under the terms of the GNU General Public License version 2 as
dnl published by the Free Software Foundation.
dnl
dnl PROGBASE is distributed in the hope that it will be useful,
dnl but WITHOUT ANY WARRANTY; without even the implied warranty of
dnl MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
dnl GNU General Public License for more details.
dnl
dnl You should have received a copy of the GNU General Public License
dnl along with this program; if not, write to the Free Software
dnl Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
dnl USA.
dnl ----------------------------------------------------------------------
dnl
dnl PP_CHECK_PROGBASE(MIN-VERSION, ACTION-IF-FOUND, ACTION-IF-NOTFOUND)
dnl ----------------------------------------------------------------------
dnl MIN-VERSION               minimum required progbase version, eg. 0.5.1
dnl                           abort with error message if version to old
dnl ACTION-IF-FOUND           action to perform if progbase was found
dnl ACTION-IF-NOTFOUND        action to perform if progbase was not found

AC_DEFUN([PP_CHECK_PROGBASE],
[# Autoconf macro for locating progbase from configure.ac
 AC_PREREQ(2.59)

 dnl Configure option
 AC_ARG_WITH([progbase],
	     [AC_HELP_STRING([--with-progbase=DIR],
			     [search for progbase in DIR])],
	     [if test "x$withval" != xyes; then
	        _progbase_instdir="$withval"
	      fi])

 if test "$_progbase_instdir"; then
   dnl To locate progbase-config
   PATH="$PATH:$_progbase_instdir:$_progbase_instdir/bin"
 fi

 dnl Use tools to get parameters
 if test -z "$PKG_CONFIG"; then
   AC_PATH_PROG([PKG_CONFIG],
		[pkg-config],
		[no],
		[$PATH:/usr/bin:/usr/local/bin])
 fi
 AC_PATH_PROG([PB_CONFIG],
	      [progbase-config],
	      [no],
	      [$PATH:/usr/bin:/usr/local/bin])

 dnl Search for progbase
 m4_ifvaln([$1],
	   [_progbase_minver="$1"
	    AC_MSG_CHECKING([for progbase - version >= $_progbase_minver])],
	   [AC_MSG_CHECKING([for progbase])])

 if test "x$PKG_CONFIG" != xno && ($PKG_CONFIG --exists progbase); then
   _progbase_CPPFLAGS=`($PKG_CONFIG --cflags progbase)`
   _progbase_LDFLAGS=`($PKG_CONFIG --libs progbase)`
   _progbase_version=`($PKG_CONFIG --modversion progbase)`
 elif test "x$PB_CONFIG" != xno; then
   _progbase_CPPFLAGS=`($PB_CONFIG --cflags)`
   _progbase_LDFLAGS=`($PB_CONFIG --libs)`
   _progbase_version=`($PB_CONFIG --version)`
 else
   _progbase_version=no
 fi

 dnl Update config.log
 echo "$as_me:$LINENO:" \
   "progbase CPPFLAGS: $_progbase_CPPFLAGS" >&AS_MESSAGE_LOG_FD
 echo "$as_me:$LINENO:" \
   "progbase LDFLAGS: $_progbase_LDFLAGS" >&AS_MESSAGE_LOG_FD
 echo "$as_me:$LINENO:" \
   "progbase version: $_progbase_version" >&AS_MESSAGE_LOG_FD

 if test "x$_progbase_version" = xno; then
   dnl progbase not found
   AC_MSG_RESULT([no])

   m4_if([$3],, [:], [$3])
 else
   dnl Check progbase version
   if test "x$_progbase_minver" != x; then
     for _var in _progbase_minver _progbase_version; do
       eval "_val=\"\$${_var}\""
       _ver=`echo $_val | sed 's/\([[0-9]]*\)\.\([[0-9]]*\)\([[abps.]]\)\([[0-9]]*\)/\1/'`
       _rev=`echo $_val | sed 's/\([[0-9]]*\)\.\([[0-9]]*\)\([[abps.]]\)\([[0-9]]*\)/\2/'`
       _typ=`echo $_val | sed 's/\([[0-9]]*\)\.\([[0-9]]*\)\([[abps.]]\)\([[0-9]]*\)/\3/'`
       _lvl=`echo $_val | sed 's/\([[0-9]]*\)\.\([[0-9]]*\)\([[abps.]]\)\([[0-9]]*\)/\4/'`
       case $_typ in
	 a)
	   _typ=0
	   ;;
	 b)
	   _typ=1
	   ;;
	 p|.)
	   _typ=2
	   ;;
	 s)
	   _typ=15
	   _lvl=255
	   ;;
	 *)
	   dnl Invalid syntax
	   echo "$as_me:$LINENO:" \
	     "parsing minimum version: must be \"[[0-9]]+\.[[0-9]]+[[sabp.]][[0-9]]+\", got \"$_progbase_minver\"" \
	     >&AS_MESSAGE_LOG_FD

	   AC_MSG_RESULT([error processing version])
	   AC_MSG_FAILURE([invalid version string in call to [PP_CHECK_PROGBASE]])
	   ;;
       esac
       _hex=`echo dummy | $AWK '{ printf("%d%02d%1d%02d", ver, rev, typ, lvl); }' "ver=$_ver" "rev=$_rev" "typ=$_typ" "lvl=$_lvl"`
       eval "${_var}_hex=\"\$_hex\""
     done

     dnl Update config.log
     echo "$as_me:$LINENO:" \
       "required version: $_progbase_minver, 0x$_progbase_minver_hex" >&AS_MESSAGE_LOG_FD
     echo "$as_me:$LINENO:" \
       "installed version: $_progbase_version, 0x$_progbase_version_hex" >&AS_MESSAGE_LOG_FD

     if test $_progbase_minver_hex -gt $_progbase_version_hex; then
       AC_MSG_RESULT([no, version $_progbase_version])
       AC_MSG_ERROR([found progbase version $_progbase_version, but required at least version $_progbase_minver])
     fi
   fi

   AC_MSG_RESULT([yes])

   dnl Add parameters to environment
   save_CPPFLAGS=$CPPFLAGS
   save_LDFLAGS=$LDFLAGS
   save_LIBS=$LIBS

   CPPFLAGS="$CPPFLAGS $_progbase_CPPFLAGS"

   for _flag in $_progbase_LDFLAGS; do
     case $_flag in
       *-lprogbase*)
	 ;;
       *-l*)
	 _progbase_LIBS="$_progbase_LIBS $_flag"
	 ;;
       *)
	 LDFLAGS="$LDFLAGS $_flag"
	 ;;
     esac
   done

   dnl Perform sanity checks
   AC_CHECK_HEADERS([progbase.h],,
		    [_progbase_unusable=yes])
   AC_CHECK_LIB([progbase], [progbase_init],,
		[_progbase_unusable=yes],
		[$_progbase_LIBS])

   LIBS="$LIBS $_progbase_LIBS"

   if test "$_progbase_unusable"; then
     CPPFLAGS=$save_CPPFLAGS
     LDFLAGS=$save_LDFLAGS
     LIBS=$save_LIBS

     m4_if([$3],, [:], [$3])
   else
     m4_if([$2],, [:], [$2])
   fi
 fi

])# PP_CHECK_PROGBASE
